# Module 1 : Cahier de Notes, cahier de laboratoire

Ce module commence par un aperçu historique de la prise de note dans le contexte plus général de l'écriture et des livres. Puis il présente des entretiens avec des chercheurs de plusieurs domaines (mathématique, histoire, sience politique, recherche en laboratoire ...). Ces entretiens montrent le glissement progressif des chercheurs vers des solutions informatiques, qui présentent des intérêts techniques évidents (comme la renumérotation automatique de notes très nombreuses, comme en parle très bien l'historienne). Le module termine par la présentation des solutions informatiques. 
L'exercice consiste à écrire un premier fichier dans le format markdown.

Le support du cours est téléchargeable [ici](https://www.fun-mooc.fr/asset-v1:inria+41016+self-paced+type@asset+block/C028AL_slides_module1-fr-gz.pdf)


## Aperçu historique 

L'évolution du livre est passée par deux étapes en Occident:
- le *volumen*, qui est rouleau écrit sur papyrus qui se déroule au moment de la lecture (entre deux rouleaux). On en trouve ecore aujourd'hui dans les synagogues pour les rouleaux de la Tora.
- le *codex*, qui descend des tablettes de cire de la période Romaine, assemblées ensemble, puis plus tard remplacées par des feuilles de vélin, puis de papier.

La tradition Juive est née à l'époque des *volumen* et s'attache donc à ce format. Il pousse à lire à haute voix et ne permet pas de prise de note sur un autre support annexe car les deux mains sont prises par les deux rouleaux (celui à enrouler et celui à dérouler). La lecture se fait au rythme de la diction, ce qui est renforcé par la difficulté de déchiffrer un texte dans lequel les mots ne sont pas séparés (et pour l'hébreux, dans lequel les accents indiquant les sons voyelles peuvent ne pas être notés).

Les traditions Chrétiennes, puis musulmannes nées plus tard, ont utilisé le format codes dès leur origine pour leur livres traditionnels.


La séparation des mots, puis des paragraphes (d'abord s'implement indiqués par les lettrines de couleur) n'apparaitra que progressivement au cours des siècles qui suivent. La lecture silencieuse n'apparaitra qu'à la fin de cette lente évolution. Elle remplacera le lien entre la lecture et l'élocution par un lien entre la lecture et la pensée, qui nous semble si naturel aujourd'hui.


## Revu des exemples pratiques de la prise de notes aujourd'hui

À travers les entrertiens et les présentations, les impératifs de la prise de notes sont:
- être techniquement simple et légère, pour que le processus soit naturel et puisse être répétés régulièrement et sans découragements ;
- permettre une relecture simple et rapide ;
- faciliter ensuite les recherches, quand les notes se sont accumulées.

L'utilisation de l'informatique est actuellement un accélérateur de recherche. Dans son entretien, l'historienne compare ses notes écrites au début sur papier avec celles qu'elle prend aujourd'hui sur un ordinateur et avoue qu'honnêtrement, elle revient maintenant très rarement sur celles en papier, plus compliquées à utiliser. On voit donc qu'à terme, le fait de pouvoir retrouver efficacement une note sur un sujet donné est un point crucial.

Par contre, la difficulté est que nos centres d'intérêt ou de recherche peuvent changer. Le classement que l'on pense efficace aujourd'hui, le sera peut être moins demain...
<!-- exemple à donner ou développer -->



## Les solutions informatiques

Plusieurs solutions informatiques sont présentées:
- le langage de balisage [markdown](https://enacit.epfl.ch/cours/markdown-pandoc)
- les logiciels permettant de *marquer* des images.
- Les logiciels de recherche de mots à travers plusieurs fichiers.
- Le logiciel se suivi de réivison *git* et ses applications directes *gitlab* et *github*


### le format markdown

Il insiste en particulier sur le format texte, qui correspond aux fichiers encodés selon un standard de représenation simple, actuellement [utf-8](https://www.utf8-chartable.de/) étant le format plus naturel. Ces formats simples vont faciliter ensuite la recherche par d'autres outils et en particulier les outils cloud, comme dans l'exemple de ces notes.

Pour conserver une présentation agréable à la lecture, le format , est format simple avec balise qui permet d'obtenir les mises en forme dont on peut avoir besoin dans une prise de notes. Ces formats de balise permettent aussi d'inclure des notes masquées, qui faciliteront les recherches par thèmes. D'autres initiatives comme la [TEI](https://tei-c.org/release/doc/tei-p5-doc/fr/html/) visent à établir des standards, qui permettraient d'utiliser plus efficacement les textes sources, s'ils étaient universellement utilisés.


### Les recherches de mots clés à travers plusieurs fichiers

Les logiciels de traitement de texte (comme Word) permettent la recherche de mots, mais uniquement sur un seul fichier. Sous Linux, il existe une application bien pratique, *grep*, qui permet de faire ce genre de recherche à travers plusieurs fichiers textes (et en généralisant ces recherches grâce aux expressions rationnelles). Cette [page d'Ubuntu](https://doc.ubuntu-fr.org/recherche_de_fichiers) présente les différentes solutions qui existent.

#### cgvg

La [page de l'auteur donne le source](http://www.uzix.org/cgvg.html). On trouve aussi d'autres explications sur [une page de Debian](https://packages.debian.org/unstable/cgvg). Cette suite n'est a priori plus maintenue, mais fonctionne bien. Elle permet de faire des recherches avec le commande `cg` puis de visualiser les résultats dans les fichiers avec `vg`.

#### docFetcher

Ce logiciel a l'intérêt d'exister sous les trois plateformes.

#### ExifTool

Ce [logiciel](https://exiftool.org/) permet de visualiser et d'écrire directement dans les métadata d'un fichier image. On peut ainsi insérer une nouvelle propriété, qui pourra à son tour être trouvées par une recherche sur un mot clé donné.

La commande [mogrify d'ImageMagick](https://imagemagick.org/script/mogrify.php) permet aussi de faire cela, mais je n'ai pas encore approfondi la desssus.


### La gestion de versions avec Git

Le logiciel [Git](https://git-scm.com/) a été dévelopé par Linus Torwald est son équipe en 2005 pour travailler en équipe sur le noyaux linux et remplacer le logiciel *bitKeeper* qui changeait alors de licence. Ce logiciel conserve les différentes versions d'une serie de fichiers (que l'on peut choisir un à un), ce qui permet les retours en arrière et aussi d'identifier et de commenter les changements. Il fonctionne de manière non centralisée: chacun conservant une copie en local, peut ensuite développer des branches alternatives. Ceci correspond pleinement à l'esprit des logiciels libres.

Mais l'application à des prises de notes est aussi très intéressante : on prend des notes, on peut revenir en arrière tout en conservant des notes alternatives qui pourraient redevenir intéressantes plus tard...

Deux applications cloud existent sur la base de ce logiciel:
- [github](https://github.com/)
- [gitlab](https://about.gitlab.com/)
 

Ces deux applications appartiennent à des entrerprises privées et ont chacune un fonctionnement commercial différent.
- github est gratuit pour les étudiants, mais devient payante pour les entreprises
- gitlab permet à chacun de se faire une version personnalisée et c'est ensuite le service qui devient payant

Ce cours utilise une version Inria de Gitlab


## Des liens utiles que j'ai retenus après ce module:

- [Lien vers La BnF sur l'histoire des écritures](http://classes.bnf.fr/ecritures/)
- [table des caractères Unicode](https://www.utf8-chartable.de/)
- [Élaboration et conversion de documents avec Markdown et Pandoc, de Jean-Daniel Bonjour](https://enacit.epfl.ch/cours/markdown-pandoc/)
- [La TEI: Text Encoding Initiative](https://tei-c.org/release/doc/tei-p5-doc/fr/html/)
- [Odette, logiciel TEI, présentation de Frédéric Glorieux](http://obvil.sorbonne-universite.site/developpements/odette)

*Autres ressources intéressantes:*
- [Qu'est-ce qu'un lieu de savoir](https://books.openedition.org/oep/650)


